(function (root, factory) {
    if (typeof define === 'function' && define.amd) {
        // AMD. Register as an anonymous module.
        define(['exports', 'echarts'], factory);
    } else if (typeof exports === 'object' && typeof exports.nodeName !== 'string') {
        // CommonJS
        factory(exports, require('echarts'));
    } else {
        // Browser globals
        factory({}, root.echarts);
    }
}(this, function (exports, echarts) {
    var log = function (msg) {
        if (typeof console !== 'undefined') {
            console && console.error && console.error(msg);
        }
    }
    if (!echarts) {
        log('ECharts is not Loaded');
        return;
    }
    if (!echarts.registerMap) {
        log('ECharts Map is not loaded')
        return;
    }
    echarts.registerMap('榆林', {"type":"FeatureCollection","features":[{"id":"610800","geometry":{"type":"Polygon","coordinates":["@@VBXDJ@DAHK@IGYAGDEFCFAHBDBBBBJFFXJH@FCHGAIYQCE@CFILOTM`KN@LB`@L@@CECGKGEKCGEEMMQEQAKDGHI@CCKGMSKDKSSOg[_Ui@GFEJGFG@GGOCMKWGGWIACAEDOAOCKKSmeMG]WIEQC[E[@]CUGaWYKaiCKBCHITIDCJYR[BG@gDMFKBKAKGKOKKEECAADIZ[BE@GAGGIQOO[@KISIOEEICOAGCEEAGBGJIFGBIGGEKY_OUKIKAIGKIEGCI@MDMFIBEAECEIGYMCGK_CIKM@OBGZ]BEACFMDCXGR@BICKQQAC@QDKBI@MCI@ICGIIKAQ@IBE@SK@A@OHOCeBIHU@EEEGCiUIAI@ULIHGBMDcBSGKGEIG]I]SUGMEUBMAECGGGGCWEeCKCIGcaQYMSOIQEYAFSAMEMMGOASBYKk@MBUCUCEMGKAgFQCMKGIGOAMAS@YBQDMTaBKAIekAI@OLUDM@K@KISCO@G@KFUHITGFCLSDG@ECEQWAI@KDIHKLGHC^QZG^CNINELGNSLafoJGDGFEAGBCHCX[ReB[JM^UYVEVIh]HIAKOQMQIGK@KFMLIjQLElERCLERQZSBGGOIEGCQ@OACCCGAIBEFKFGBEDSAY@GHIfkBGAGIIGKKGQIACDYAGKMKSCcDO@GAEGMGSCCGCIAcAICwEOCqAGAKCGECIEaO]AMAQBUHMNKVE`CN@PCZGJEDGAGCKIM_OAE@EDIVW@I@GCEICEAeBGECECKAQEMUQO]a]}OOYWoaGGCEAMDaCEGIEEgQQKOSEIUSS]MKICKA[BKAQEGGAGBENGhCFAFEBCAGCEMEQ@KD[VGDKBKB[AECECAEBIJOLIdKNOLUCAEIO@GBA@@GGEIAGCMBMDGGCICCBIACI@AJDFINBJMXQNID[Bg]UIO@OFGVALMHWFYXyP[DS@CAGKKUEGKEeIiMOEOAEFOLO@SFkvULOFSJIJC`BPSpMTCPCBHPBNLZFT@VCFGBKAECQMEAEKEACBU\\CPBFJRBVEJMLGJabBDJFRDJALIFKLCV@\\JFHBJ@LDJNRHZBZCNSJKBCFICEGC@ODK@GVGAGEICI@OFIJEDWHQDGDEHGdGLCBAA@WCCOIGGACHUHIGYMBAVAFEBAAEKIGEAC@CDEBSCiPSGGEKIEIMI]NcAANEDUEEBBHPXR^HTJDD@FOBALBTAFBEVFFAFIPERAVI@DFGDAA@CFKSCG@ILEJAJCB@HFLCJBHO@ADDLHJ@DMJA@C@OIIBSFKHAXLTADOPYFaIOOAIDI@SBOIWJeFYNOFMBKNGLET_NQLEJOFMBY@OHCLILCBYAKCKOMgEIIEKA[@IEOMGEW@IGWEECo{IeOUWIQABKHILIDGBMAAC@EBEHIFkBIEEOAAS@EDGBQIIESFWIEMAS@AAAUXC@KGCAMFMIECOBgLAAAEFK@KACGKIB]HMNIFKBcFC@ACK[EAG@MDIAELOBC@ES_[IIAAE@EDAJBHEFO@iHIDAAAE@GFEDGCMCAE@MHEEKCGMEECGCAKCIAQ@CCCEGcEKCCI@GHE@MGMCEBABALI@UGS@IEASA@CBCNOnUTEBC@@A@OPUAGCAIAAA@QCEACDQACIM@CHGLEBACW@GDALBL@NCBABmAG_B]FEASKCC@KACEAE@WFCAAAEKMQGGAAAIAAEA[TEBEAIQCCMBABCHC@QC@ADKJQBEOGQU@KJE`GNBDAJUFIHENAPGXCHIFM@CCCSGCE@KFQ@ESKCECKCGEAEHCAOGAC@CAECAC@IDCFBNCDC@QKSAEB]PYBEFERCBQAIMGBQP@DBLAJEDKDGFCDCPAFKFG@AAEIIEcKCBKHEAACAMEKMQBS@CEAE@OHC@ICKE@AHA@AKAGDAJABGCGOEDODCFA@CAIGA@ORGCCBKNMBQAIBEFGPENBFBDNB^IH@FDDDBFFDXFJFFDBHAHELEF@D@FTLDDATJT@FIRMNIRFVHVBNALHNDNKVKP[RKNGNAHEVBDNL@BCF_JSGEBQVGDkPADBBDDRHFBPCBDBNBBN@DBBV@FEDUJmdWHGXC\\@HALEPH^@VALKNOZIDG@CCAA@EFK@IACCA@CBK@AGCAIE@MNID[FS@CBABBFNXBFADQEAMKIUgCAKEIIMCGGEAqO[CWGGEcBKAEAg]@CHMLGLOFC\\GAGEKAEBEFETIFObIJCFI@CAQACA@MFC@@CDM@ECCEAEBEJABGAOE@INCD@@IAKCCKGESSCQKQMCQGGECEAIDGASQGAOBKBEL@PCNHVCFMDG@EAAICIGCK@KBEDCJCVQCJUAAMEG_AqEMU[MGSCE@CBGHCBGBSGMDCAGGGAKDKFUCSI{UAA@UAEA@EBIDE@ECKMAOAAEDC@CGE@AD@DCCCHA@@EGD@DMLAFGBMAOF@AAKCEC@ADMEGBBQGFIDCLDF@DEJ@FJ^APCPUh@RABQDB^InGXKPCBWGKH[AADBDBFHHDFALCDCD[@OFE@OMKQCAUBECOQQOCGCAI@E@@C@EJEBECY@CJ@BABCAEMESCEAKMBEPKPFFABA@CSaMBIAEHCDG@ECGFGABDCDCBDEAEBACGCBOMMDECIKAGDCB@DBDAFEHBFLD@NMDC@AEAIK@CBEJKAGfUDEBGMEEGKGMWCCQ@GBADBHABSLOBEAEA@C@ELMBIH@BACC@AH@DCBKAIFED@DCHA@EBIJSDACEFKNBATCFDNBBZAAUDGDAD@JF@RBFLDBA@GLEBCHEL@HGGGBEACBKKBCCE@@AC@BCACGFECCHE@CBBN@BECAECC@AB@BEG@CCI@BGAECFAEABETCFA@GKEQNMLCBCIOACNGFEJgPMFOAM@ODI@GGY@EJC@GIQeISGUOIIMIIAOIIAGEE@CCKCOAAA@ECJ]HUFGJEFMF]BOAYSS@IDObAFIFCFH@JLBHAHtSXUHYCeMSCMHKDcAFMFCFYTOJGAEAaUIAABATAFCBQDHDBD@@C@ABBDD@DJBBD@CFDFEDFDAB@FC@ABBBCDDBCB@AA@@FCB@BDB@FCB@DAAABBBABADCD@DBBCBAHBB@BEHDDA@AF@BF@CF@DB@BDEDBDCDBHCDBFADC@BD@DC@CD@BDBCDFDEDAHIFBBHAJR@HDBEFCNGFEFJH@FEH@FAB@DCDBJEBEHLCHBLEB@QPALHD@BC@GCGDDDLBALADCDABDDHBFEBBBAAADA@@BCDADE@ABCFCDBBCJELQJNAHH@@DBDD@FDFLDD@DLHADBFADHDCDFBADBBABDFEDHF@BA@AFFBCDBDAFCFBDCBBDEB@FCBBDEB@HCBAJABC@EDF@ADED@FIAEFQJ]VWNIH@F@DFDVDPHHATEF@BB@D@DABBDAFBDCBALCB@FAACFBDGFBBADEB@BCD@FCAAFIDADKFKJELK\\GX@HEJBLJPBJCXAD@NThFTRBRAn@TDHNN^JHDlZ\\VJLFTJHFLFTDTDFDPFJAHGJsMWFgt\\GHBDDfAPHHDHFCH@DRLDDpnFBhGDDB\\IByJI\\FLhDJAVMFAJ@nJJ@PDZRNNHPDNDXCZH^JLpN|Hh@ZNN@@F@BE@KAIFADBBLLD@FAAKDAJ@FBD@FIFCHMLCL@hhLTH^TrC^OLvVNZD@P@FEKKBGfKjeVKK\\IXAbIDBHF`CJCNK]@@LJL@XGRCAANC\\QO@CCg\\gAUBAX@HCJMDK@YBCNMDEEYS]@AR_FC~FJAXMJCIPELENMLGZ@NDVPLF\\AJBJHJNHPFF\\L`FXBxCZELGJQHMFETGfAJBNFNHJDJBPAFlFfLpVDVPAfOªyRCR@bHnNN\\VNHTBX@RARER@TDPLNX@PCRMhAlDL`hBPG^GTAX@H~DFPfJNDL@NIXMPcRBr@bORE`WXYBUTsJKfYBGFYDMJMPODAL@dRNBJBBBLZBHAVFHTJH@TEVJDBAHEPFFLJJNRrhBZ@BJixTXRrIRh±a`INANDJBHK^@DHFNDLHFLRTT\\@DIJUVBFBJRZHXNPNLf¢RH|fJHHLDFFZ@VCFKP@HDDVHJFFHPJRDFDXZRJNDRPftJF\\JVJDDJJJRPVBNDFPNLHZXRNhhXVXPL@LCrgbGDBJJRTdTJJ@DADMFQPIH_ZCDAFCNJT@PLVDFbJbHNDZ@JBLFDHHhBHLNzj@FAHDJNLdVZXNBBBXXLHJJHBHCTSjaH@NNZPHDFF^RFFPTFFHDDBF@LIFABFCF@BPPFLJJLLFLFL@FhJLPFAHGTLhIH]T@DNZfGHFTljBLP`^LPTRJFRD`XD@lnfPDBJLDJRNRD\\GRGHOJIz@FF[h]^ALTDNJPHHDDLTHNHFB^TFFBD@DIH[NIHUJQNOTEDUJICO@EDKJEHEP@BDBLGDB@LJPZHDFDDD@JCLOLGD@BCLEHG@EJCBEHCBGHIBEDADGHCNQD@BANAFBJ@PAJ@HCNDNCRJnFNFFFZFPHHDF@HCH@BBBJDDLHDDJDJHFBN@NBfVV@LDFFFBFFLDXFNLP@TBJEFBADGFGJG`EP@FGRQ^CREJINKTEBCFAHIPIHCBSAS@CBIPEVAPE^BBNHBJAJBDJFPFDFABNG®aJLL@\\MPQJGrDPABGYQMIFCVGHGPGHKLGBAAADABGRK@CF@JEFINGHGJCFGJCFGTEPKTEHCFCAEFABCFABGFILDTPZNDDFLFFLBDD@DEDSJHZRZBJJD^@\\GLCDCFIROVALBZRBDCJAJB@HBJADDDAPMLC@CJEbaDK@OBEDCNIFECCECCEFEBKLGLQJAFAHQDGJEJEJBDADCFEHEJA@ADABBH@@BD@HBDABBF@BDDABBH@DADDLBBBBADDFBRENIFAPJND@BBDFDRTPPBD@HBDPH@DCJBF@FEFDDD@LHAFBF@HCDDFAHHDADDHLLFHLH@BNHLTJFPBFFTV@JFHTBBF@FFLNHLHHBBDCDADNLLVLLBFADPJBD@FBBPNDLHJHDJ@HBFFNTFB^FTCJFL@RJRBJDPENHHDFF@DL@VNJL@FDDNDHFNAFBHF@BHD@JDBJ@BED@@B@DOF@DDBP@HCBGACBKDChHHCJ@RDPAHBRBTHNHBFBP^RFBFCDMDCXMAADIAAEABIEA@CHAEG@ECGI@@CDCDB@OG@@EEEFA@CCAEDEACC_SAGDIAAO@KEAECOEIRI@GGAEDE@GAMK@M@CCEOCEBIAGGQEBOISNIDC@GFGACEACEBIFGPBBD@BBDJDFFDBF@XO@ES]AEAGBGJMDCLMPGJ@RFFHBD"],"encodeOffsets":[[113793,40312]]},"properties":{"cp":[109.741193,38.290162],"name":"榆林市","childNum":1}}],"UTF8Encoding":true});
}));
